package java.util;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;






































































































public class ArrayList<E>
  extends AbstractList<E>
  implements List<E>, RandomAccess, Cloneable, Serializable
{
  private static final long serialVersionUID = 8683452581122892189L;
  private static final int DEFAULT_CAPACITY = 10;
  private static final Object[] EMPTY_ELEMENTDATA = new Object[0];
  




  private transient Object[] elementData;
  




  private int size;
  




  private static final int MAX_ARRAY_SIZE = 2147483639;
  




  public ArrayList(int paramInt)
  {
    if (paramInt < 0) {
      throw new IllegalArgumentException("Illegal Capacity: " + paramInt);
    }
    this.elementData = new Object[paramInt];
  }
  



  public ArrayList()
  {
    this.elementData = EMPTY_ELEMENTDATA;
  }
  







  public ArrayList(Collection<? extends E> paramCollection)
  {
    this.elementData = paramCollection.toArray();
    this.size = this.elementData.length;
    
    if (this.elementData.getClass() != [Ljava.lang.Object.class) {
      this.elementData = Arrays.copyOf(this.elementData, this.size, [Ljava.lang.Object.class);
    }
  }
  



  public void trimToSize()
  {
    this.modCount += 1;
    if (this.size < this.elementData.length) {
      this.elementData = Arrays.copyOf(this.elementData, this.size);
    }
  }
  






  public void ensureCapacity(int paramInt)
  {
    int i = this.elementData != EMPTY_ELEMENTDATA ? 0 : 10;
    





    if (paramInt > i) {
      ensureExplicitCapacity(paramInt);
    }
  }
  
  private void ensureCapacityInternal(int paramInt) {
    if (this.elementData == EMPTY_ELEMENTDATA) {
      paramInt = Math.max(10, paramInt);
    }
    
    ensureExplicitCapacity(paramInt);
  }
  
  private void ensureExplicitCapacity(int paramInt) {
    this.modCount += 1;
    

    if (paramInt - this.elementData.length > 0) {
      grow(paramInt);
    }
  }
  













  private void grow(int paramInt)
  {
    int i = this.elementData.length;
    int j = i + (i >> 1);
    if (j - paramInt < 0)
      j = paramInt;
    if (j - 2147483639 > 0) {
      j = hugeCapacity(paramInt);
    }
    this.elementData = Arrays.copyOf(this.elementData, j);
  }
  
  private static int hugeCapacity(int paramInt) {
    if (paramInt < 0)
      throw new OutOfMemoryError();
    return paramInt > 2147483639 ? Integer.MAX_VALUE : 2147483639;
  }
  






  public int size()
  {
    return this.size;
  }
  




  public boolean isEmpty()
  {
    return this.size == 0;
  }
  








  public boolean contains(Object paramObject)
  {
    return indexOf(paramObject) >= 0;
  }
  



  public int indexOf(Object paramObject)
  {
    int i;
    

    if (paramObject == null) {
      for (i = 0; i < this.size; i++)
        if (this.elementData[i] == null)
          return i;
    } else {
      for (i = 0; i < this.size; i++)
        if (paramObject.equals(this.elementData[i]))
          return i;
    }
    return -1;
  }
  



  public int lastIndexOf(Object paramObject)
  {
    int i;
    

    if (paramObject == null) {
      for (i = this.size - 1; i >= 0; i--)
        if (this.elementData[i] == null)
          return i;
    } else {
      for (i = this.size - 1; i >= 0; i--)
        if (paramObject.equals(this.elementData[i]))
          return i;
    }
    return -1;
  }
  





  public Object clone()
  {
    try
    {
      ArrayList localArrayList = (ArrayList)super.clone();
      localArrayList.elementData = Arrays.copyOf(this.elementData, this.size);
      localArrayList.modCount = 0;
      return localArrayList;
    }
    catch (CloneNotSupportedException localCloneNotSupportedException) {
      throw new InternalError();
    }
  }
  













  public Object[] toArray()
  {
    return Arrays.copyOf(this.elementData, this.size);
  }
  
























  public <T> T[] toArray(T[] paramArrayOfT)
  {
    if (paramArrayOfT.length < this.size)
    {
      return (Object[])Arrays.copyOf(this.elementData, this.size, paramArrayOfT.getClass()); }
    System.arraycopy(this.elementData, 0, paramArrayOfT, 0, this.size);
    if (paramArrayOfT.length > this.size)
      paramArrayOfT[this.size] = null;
    return paramArrayOfT;
  }
  


  E elementData(int paramInt)
  {
    return this.elementData[paramInt];
  }
  






  public E get(int paramInt)
  {
    rangeCheck(paramInt);
    
    return elementData(paramInt);
  }
  








  public E set(int paramInt, E paramE)
  {
    rangeCheck(paramInt);
    
    Object localObject = elementData(paramInt);
    this.elementData[paramInt] = paramE;
    return localObject;
  }
  





  public boolean add(E paramE)
  {
    ensureCapacityInternal(this.size + 1);
    this.elementData[(this.size++)] = paramE;
    return true;
  }
  








  public void add(int paramInt, E paramE)
  {
    rangeCheckForAdd(paramInt);
    
    ensureCapacityInternal(this.size + 1);
    System.arraycopy(this.elementData, paramInt, this.elementData, paramInt + 1, this.size - paramInt);
    
    this.elementData[paramInt] = paramE;
    this.size += 1;
  }
  








  public E remove(int paramInt)
  {
    rangeCheck(paramInt);
    
    this.modCount += 1;
    Object localObject = elementData(paramInt);
    
    int i = this.size - paramInt - 1;
    if (i > 0) {
      System.arraycopy(this.elementData, paramInt + 1, this.elementData, paramInt, i);
    }
    this.elementData[(--this.size)] = null;
    
    return localObject;
  }
  






  public boolean remove(Object paramObject)
  {
    int i;
    




    if (paramObject == null) {
      for (i = 0; i < this.size; i++)
        if (this.elementData[i] == null) {
          fastRemove(i);
          return true;
        }
    } else {
      for (i = 0; i < this.size; i++)
        if (paramObject.equals(this.elementData[i])) {
          fastRemove(i);
          return true;
        }
    }
    return false;
  }
  



  private void fastRemove(int paramInt)
  {
    this.modCount += 1;
    int i = this.size - paramInt - 1;
    if (i > 0) {
      System.arraycopy(this.elementData, paramInt + 1, this.elementData, paramInt, i);
    }
    this.elementData[(--this.size)] = null;
  }
  



  public void clear()
  {
    this.modCount += 1;
    

    for (int i = 0; i < this.size; i++) {
      this.elementData[i] = null;
    }
    this.size = 0;
  }
  












  public boolean addAll(Collection<? extends E> paramCollection)
  {
    Object[] arrayOfObject = paramCollection.toArray();
    int i = arrayOfObject.length;
    ensureCapacityInternal(this.size + i);
    System.arraycopy(arrayOfObject, 0, this.elementData, this.size, i);
    this.size += i;
    return i != 0;
  }
  














  public boolean addAll(int paramInt, Collection<? extends E> paramCollection)
  {
    rangeCheckForAdd(paramInt);
    
    Object[] arrayOfObject = paramCollection.toArray();
    int i = arrayOfObject.length;
    ensureCapacityInternal(this.size + i);
    
    int j = this.size - paramInt;
    if (j > 0) {
      System.arraycopy(this.elementData, paramInt, this.elementData, paramInt + i, j);
    }
    
    System.arraycopy(arrayOfObject, 0, this.elementData, paramInt, i);
    this.size += i;
    return i != 0;
  }
  













  protected void removeRange(int paramInt1, int paramInt2)
  {
    this.modCount += 1;
    int i = this.size - paramInt2;
    System.arraycopy(this.elementData, paramInt2, this.elementData, paramInt1, i);
    


    int j = this.size - (paramInt2 - paramInt1);
    for (int k = j; k < this.size; k++) {
      this.elementData[k] = null;
    }
    this.size = j;
  }
  





  private void rangeCheck(int paramInt)
  {
    if (paramInt >= this.size) {
      throw new IndexOutOfBoundsException(outOfBoundsMsg(paramInt));
    }
  }
  

  private void rangeCheckForAdd(int paramInt)
  {
    if ((paramInt > this.size) || (paramInt < 0)) {
      throw new IndexOutOfBoundsException(outOfBoundsMsg(paramInt));
    }
  }
  



  private String outOfBoundsMsg(int paramInt)
  {
    return "Index: " + paramInt + ", Size: " + this.size;
  }
  














  public boolean removeAll(Collection<?> paramCollection)
  {
    return batchRemove(paramCollection, false);
  }
  















  public boolean retainAll(Collection<?> paramCollection)
  {
    return batchRemove(paramCollection, true);
  }
  
  /* Error */
  private boolean batchRemove(Collection<?> paramCollection, boolean paramBoolean)
  {
    // Byte code:
    //   0: aload_0
    //   1: getfield 240	java/util/ArrayList:elementData	[Ljava/lang/Object;
    //   4: astore_3
    //   5: iconst_0
    //   6: istore 4
    //   8: iconst_0
    //   9: istore 5
    //   11: iconst_0
    //   12: istore 6
    //   14: iload 4
    //   16: aload_0
    //   17: getfield 238	java/util/ArrayList:size	I
    //   20: if_icmpge +34 -> 54
    //   23: aload_1
    //   24: aload_3
    //   25: iload 4
    //   27: aaload
    //   28: invokeinterface 280 2 0
    //   33: iload_2
    //   34: if_icmpne +14 -> 48
    //   37: aload_3
    //   38: iload 5
    //   40: iinc 5 1
    //   43: aload_3
    //   44: iload 4
    //   46: aaload
    //   47: aastore
    //   48: iinc 4 1
    //   51: goto -37 -> 14
    //   54: iload 4
    //   56: aload_0
    //   57: getfield 238	java/util/ArrayList:size	I
    //   60: if_icmpeq +31 -> 91
    //   63: aload_3
    //   64: iload 4
    //   66: aload_3
    //   67: iload 5
    //   69: aload_0
    //   70: getfield 238	java/util/ArrayList:size	I
    //   73: iload 4
    //   75: isub
    //   76: invokestatic 259	java/lang/System:arraycopy	(Ljava/lang/Object;ILjava/lang/Object;II)V
    //   79: iload 5
    //   81: aload_0
    //   82: getfield 238	java/util/ArrayList:size	I
    //   85: iload 4
    //   87: isub
    //   88: iadd
    //   89: istore 5
    //   91: iload 5
    //   93: aload_0
    //   94: getfield 238	java/util/ArrayList:size	I
    //   97: if_icmpeq +155 -> 252
    //   100: iload 5
    //   102: istore 7
    //   104: iload 7
    //   106: aload_0
    //   107: getfield 238	java/util/ArrayList:size	I
    //   110: if_icmpge +14 -> 124
    //   113: aload_3
    //   114: iload 7
    //   116: aconst_null
    //   117: aastore
    //   118: iinc 7 1
    //   121: goto -17 -> 104
    //   124: aload_0
    //   125: dup
    //   126: getfield 237	java/util/ArrayList:modCount	I
    //   129: aload_0
    //   130: getfield 238	java/util/ArrayList:size	I
    //   133: iload 5
    //   135: isub
    //   136: iadd
    //   137: putfield 237	java/util/ArrayList:modCount	I
    //   140: aload_0
    //   141: iload 5
    //   143: putfield 238	java/util/ArrayList:size	I
    //   146: iconst_1
    //   147: istore 6
    //   149: goto +103 -> 252
    //   152: astore 8
    //   154: iload 4
    //   156: aload_0
    //   157: getfield 238	java/util/ArrayList:size	I
    //   160: if_icmpeq +31 -> 191
    //   163: aload_3
    //   164: iload 4
    //   166: aload_3
    //   167: iload 5
    //   169: aload_0
    //   170: getfield 238	java/util/ArrayList:size	I
    //   173: iload 4
    //   175: isub
    //   176: invokestatic 259	java/lang/System:arraycopy	(Ljava/lang/Object;ILjava/lang/Object;II)V
    //   179: iload 5
    //   181: aload_0
    //   182: getfield 238	java/util/ArrayList:size	I
    //   185: iload 4
    //   187: isub
    //   188: iadd
    //   189: istore 5
    //   191: iload 5
    //   193: aload_0
    //   194: getfield 238	java/util/ArrayList:size	I
    //   197: if_icmpeq +52 -> 249
    //   200: iload 5
    //   202: istore 9
    //   204: iload 9
    //   206: aload_0
    //   207: getfield 238	java/util/ArrayList:size	I
    //   210: if_icmpge +14 -> 224
    //   213: aload_3
    //   214: iload 9
    //   216: aconst_null
    //   217: aastore
    //   218: iinc 9 1
    //   221: goto -17 -> 204
    //   224: aload_0
    //   225: dup
    //   226: getfield 237	java/util/ArrayList:modCount	I
    //   229: aload_0
    //   230: getfield 238	java/util/ArrayList:size	I
    //   233: iload 5
    //   235: isub
    //   236: iadd
    //   237: putfield 237	java/util/ArrayList:modCount	I
    //   240: aload_0
    //   241: iload 5
    //   243: putfield 238	java/util/ArrayList:size	I
    //   246: iconst_1
    //   247: istore 6
    //   249: aload 8
    //   251: athrow
    //   252: iload 6
    //   254: ireturn
    // Line number table:
    //   Java source line #695	-> byte code offset #0
    //   Java source line #696	-> byte code offset #5
    //   Java source line #697	-> byte code offset #11
    //   Java source line #699	-> byte code offset #14
    //   Java source line #700	-> byte code offset #23
    //   Java source line #701	-> byte code offset #37
    //   Java source line #699	-> byte code offset #48
    //   Java source line #705	-> byte code offset #54
    //   Java source line #706	-> byte code offset #63
    //   Java source line #709	-> byte code offset #79
    //   Java source line #711	-> byte code offset #91
    //   Java source line #713	-> byte code offset #100
    //   Java source line #714	-> byte code offset #113
    //   Java source line #713	-> byte code offset #118
    //   Java source line #715	-> byte code offset #124
    //   Java source line #716	-> byte code offset #140
    //   Java source line #717	-> byte code offset #146
    //   Java source line #705	-> byte code offset #152
    //   Java source line #706	-> byte code offset #163
    //   Java source line #709	-> byte code offset #179
    //   Java source line #711	-> byte code offset #191
    //   Java source line #713	-> byte code offset #200
    //   Java source line #714	-> byte code offset #213
    //   Java source line #713	-> byte code offset #218
    //   Java source line #715	-> byte code offset #224
    //   Java source line #716	-> byte code offset #240
    //   Java source line #717	-> byte code offset #246
    //   Java source line #720	-> byte code offset #252
    // Local variable table:
    //   start	length	slot	name	signature
    //   0	255	0	this	ArrayList
    //   0	255	1	paramCollection	Collection<?>
    //   0	255	2	paramBoolean	boolean
    //   4	210	3	arrayOfObject	Object[]
    //   6	182	4	i	int
    //   9	233	5	j	int
    //   12	241	6	bool	boolean
    //   102	17	7	k	int
    //   152	98	8	localObject	Object
    //   202	17	9	m	int
    // Exception table:
    //   from	to	target	type
    //   14	54	152	finally
    //   152	154	152	finally
  }
  
  private void writeObject(ObjectOutputStream paramObjectOutputStream)
    throws IOException
  {
    int i = this.modCount;
    paramObjectOutputStream.defaultWriteObject();
    

    paramObjectOutputStream.writeInt(this.size);
    

    for (int j = 0; j < this.size; j++) {
      paramObjectOutputStream.writeObject(this.elementData[j]);
    }
    
    if (this.modCount != i) {
      throw new ConcurrentModificationException();
    }
  }
  



  private void readObject(ObjectInputStream paramObjectInputStream)
    throws IOException, ClassNotFoundException
  {
    this.elementData = EMPTY_ELEMENTDATA;
    

    paramObjectInputStream.defaultReadObject();
    

    paramObjectInputStream.readInt();
    
    if (this.size > 0)
    {
      ensureCapacityInternal(this.size);
      
      Object[] arrayOfObject = this.elementData;
      
      for (int i = 0; i < this.size; i++) {
        arrayOfObject[i] = paramObjectInputStream.readObject();
      }
    }
  }
  











  public ListIterator<E> listIterator(int paramInt)
  {
    if ((paramInt < 0) || (paramInt > this.size))
      throw new IndexOutOfBoundsException("Index: " + paramInt);
    return new ListItr(paramInt);
  }
  







  public ListIterator<E> listIterator()
  {
    return new ListItr(0);
  }
  






  public Iterator<E> iterator()
  {
    return new Itr(null);
  }
  
  private class Itr implements Iterator<E> {
    int cursor;
    
    private Itr() {}
    
    int lastRet = -1;
    int expectedModCount = ArrayList.this.modCount;
    
    public boolean hasNext() {
      return this.cursor != ArrayList.this.size;
    }
    
    public E next()
    {
      checkForComodification();
      int i = this.cursor;
      if (i >= ArrayList.this.size)
        throw new NoSuchElementException();
      Object[] arrayOfObject = ArrayList.this.elementData;
      if (i >= arrayOfObject.length)
        throw new ConcurrentModificationException();
      this.cursor = (i + 1);
      return arrayOfObject[(this.lastRet = i)];
    }
    
    public void remove() {
      if (this.lastRet < 0)
        throw new IllegalStateException();
      checkForComodification();
      try
      {
        ArrayList.this.remove(this.lastRet);
        this.cursor = this.lastRet;
        this.lastRet = -1;
        this.expectedModCount = ArrayList.this.modCount;
      } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
        throw new ConcurrentModificationException();
      }
    }
    
    final void checkForComodification() {
      if (ArrayList.this.modCount != this.expectedModCount) {
        throw new ConcurrentModificationException();
      }
    }
  }
  
  private class ListItr extends ArrayList<E>.Itr implements ListIterator<E>
  {
    ListItr(int paramInt)
    {
      super(null);
      this.cursor = paramInt;
    }
    
    public boolean hasPrevious() {
      return this.cursor != 0;
    }
    
    public int nextIndex() {
      return this.cursor;
    }
    
    public int previousIndex() {
      return this.cursor - 1;
    }
    
    public E previous()
    {
      checkForComodification();
      int i = this.cursor - 1;
      if (i < 0)
        throw new NoSuchElementException();
      Object[] arrayOfObject = ArrayList.this.elementData;
      if (i >= arrayOfObject.length)
        throw new ConcurrentModificationException();
      this.cursor = i;
      return arrayOfObject[(this.lastRet = i)];
    }
    
    public void set(E paramE) {
      if (this.lastRet < 0)
        throw new IllegalStateException();
      checkForComodification();
      try
      {
        ArrayList.this.set(this.lastRet, paramE);
      } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
        throw new ConcurrentModificationException();
      }
    }
    
    public void add(E paramE) {
      checkForComodification();
      try
      {
        int i = this.cursor;
        ArrayList.this.add(i, paramE);
        this.cursor = (i + 1);
        this.lastRet = -1;
        this.expectedModCount = ArrayList.this.modCount;
      } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
        throw new ConcurrentModificationException();
      }
    }
  }
  




























  public List<E> subList(int paramInt1, int paramInt2)
  {
    subListRangeCheck(paramInt1, paramInt2, this.size);
    return new SubList(this, 0, paramInt1, paramInt2);
  }
  
  static void subListRangeCheck(int paramInt1, int paramInt2, int paramInt3) {
    if (paramInt1 < 0)
      throw new IndexOutOfBoundsException("fromIndex = " + paramInt1);
    if (paramInt2 > paramInt3)
      throw new IndexOutOfBoundsException("toIndex = " + paramInt2);
    if (paramInt1 > paramInt2) {
      throw new IllegalArgumentException("fromIndex(" + paramInt1 + ") > toIndex(" + paramInt2 + ")");
    }
  }
  
  private class SubList extends AbstractList<E> implements RandomAccess
  {
    private final AbstractList<E> parent;
    private final int parentOffset;
    private final int offset;
    int size;
    
    SubList(int paramInt1, int paramInt2, int paramInt3) {
      this.parent = paramInt1;
      this.parentOffset = paramInt3;
      this.offset = (paramInt2 + paramInt3);
      int i; this.size = (i - paramInt3);
      this.modCount = ArrayList.this.modCount;
    }
    
    public E set(int paramInt, E paramE) {
      rangeCheck(paramInt);
      checkForComodification();
      Object localObject = ArrayList.this.elementData(this.offset + paramInt);
      ArrayList.this.elementData[(this.offset + paramInt)] = paramE;
      return localObject;
    }
    
    public E get(int paramInt) {
      rangeCheck(paramInt);
      checkForComodification();
      return ArrayList.this.elementData(this.offset + paramInt);
    }
    
    public int size() {
      checkForComodification();
      return this.size;
    }
    
    public void add(int paramInt, E paramE) {
      rangeCheckForAdd(paramInt);
      checkForComodification();
      this.parent.add(this.parentOffset + paramInt, paramE);
      this.modCount = this.parent.modCount;
      this.size += 1;
    }
    
    public E remove(int paramInt) {
      rangeCheck(paramInt);
      checkForComodification();
      Object localObject = this.parent.remove(this.parentOffset + paramInt);
      this.modCount = this.parent.modCount;
      this.size -= 1;
      return localObject;
    }
    
    protected void removeRange(int paramInt1, int paramInt2) {
      checkForComodification();
      this.parent.removeRange(this.parentOffset + paramInt1, this.parentOffset + paramInt2);
      
      this.modCount = this.parent.modCount;
      this.size -= paramInt2 - paramInt1;
    }
    
    public boolean addAll(Collection<? extends E> paramCollection) {
      return addAll(this.size, paramCollection);
    }
    
    public boolean addAll(int paramInt, Collection<? extends E> paramCollection) {
      rangeCheckForAdd(paramInt);
      int i = paramCollection.size();
      if (i == 0) {
        return false;
      }
      checkForComodification();
      this.parent.addAll(this.parentOffset + paramInt, paramCollection);
      this.modCount = this.parent.modCount;
      this.size += i;
      return true;
    }
    
    public Iterator<E> iterator() {
      return listIterator();
    }
    
    public ListIterator<E> listIterator(final int paramInt) {
      checkForComodification();
      rangeCheckForAdd(paramInt);
      final int i = this.offset;
      
      new ListIterator() {
        int cursor = paramInt;
        int lastRet = -1;
        int expectedModCount = ArrayList.this.modCount;
        
        public boolean hasNext() {
          return this.cursor != ArrayList.SubList.this.size;
        }
        
        public E next()
        {
          checkForComodification();
          int i = this.cursor;
          if (i >= ArrayList.SubList.this.size)
            throw new NoSuchElementException();
          Object[] arrayOfObject = ArrayList.this.elementData;
          if (i + i >= arrayOfObject.length)
            throw new ConcurrentModificationException();
          this.cursor = (i + 1);
          return arrayOfObject[(i + (this.lastRet = i))];
        }
        
        public boolean hasPrevious() {
          return this.cursor != 0;
        }
        
        public E previous()
        {
          checkForComodification();
          int i = this.cursor - 1;
          if (i < 0)
            throw new NoSuchElementException();
          Object[] arrayOfObject = ArrayList.this.elementData;
          if (i + i >= arrayOfObject.length)
            throw new ConcurrentModificationException();
          this.cursor = i;
          return arrayOfObject[(i + (this.lastRet = i))];
        }
        
        public int nextIndex() {
          return this.cursor;
        }
        
        public int previousIndex() {
          return this.cursor - 1;
        }
        
        public void remove() {
          if (this.lastRet < 0)
            throw new IllegalStateException();
          checkForComodification();
          try
          {
            ArrayList.SubList.this.remove(this.lastRet);
            this.cursor = this.lastRet;
            this.lastRet = -1;
            this.expectedModCount = ArrayList.this.modCount;
          } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
            throw new ConcurrentModificationException();
          }
        }
        
        public void set(E paramAnonymousE) {
          if (this.lastRet < 0)
            throw new IllegalStateException();
          checkForComodification();
          try
          {
            ArrayList.this.set(i + this.lastRet, paramAnonymousE);
          } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
            throw new ConcurrentModificationException();
          }
        }
        
        public void add(E paramAnonymousE) {
          checkForComodification();
          try
          {
            int i = this.cursor;
            ArrayList.SubList.this.add(i, paramAnonymousE);
            this.cursor = (i + 1);
            this.lastRet = -1;
            this.expectedModCount = ArrayList.this.modCount;
          } catch (IndexOutOfBoundsException localIndexOutOfBoundsException) {
            throw new ConcurrentModificationException();
          }
        }
        
        final void checkForComodification() {
          if (this.expectedModCount != ArrayList.this.modCount)
            throw new ConcurrentModificationException();
        }
      };
    }
    
    public List<E> subList(int paramInt1, int paramInt2) {
      ArrayList.subListRangeCheck(paramInt1, paramInt2, this.size);
      return new SubList(ArrayList.this, this, this.offset, paramInt1, paramInt2);
    }
    
    private void rangeCheck(int paramInt) {
      if ((paramInt < 0) || (paramInt >= this.size))
        throw new IndexOutOfBoundsException(outOfBoundsMsg(paramInt));
    }
    
    private void rangeCheckForAdd(int paramInt) {
      if ((paramInt < 0) || (paramInt > this.size))
        throw new IndexOutOfBoundsException(outOfBoundsMsg(paramInt));
    }
    
    private String outOfBoundsMsg(int paramInt) {
      return "Index: " + paramInt + ", Size: " + this.size;
    }
    
    private void checkForComodification() {
      if (ArrayList.this.modCount != this.modCount) {
        throw new ConcurrentModificationException();
      }
    }
  }
}
